==> deepin-image-viewer_5.7.8.orig.tar.xz: deepin-image-viewer-5.7.8/src/translations/deepin-image-viewer_da.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="da" version="2.1">
<context>
    <name>Application</name>
    <message>
        <source>Image Viewer</source>
        <translation>Billedfremviser</translation>
    </message>
    <message>
        <source>Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
        <translation>Billedfremviser er et værktøj til billedfremvisning med flot brugerflade og god ydelse.</translation>
    </message>
</context>
<context>
    <name>CountingThread</name>
    <message>
        <source>Images</source>
        <translation>Billeder</translation>
    </message>
</context>
<context>
    <name>ExtensionPanel</name>
    <message>
        <source>Image info</source>
        <translation>Billedinfo</translation>
    </message>
    <message>
        <source>Alt+Return</source>
        <translation>Alt+Retur</translation>
    </message>
    <message>
        <source>Alt+Enter</source>
        <translation>Alt+Enter</translation>
    </message>
</context>
<context>
    <name>ImageInfoWidget</name>
    <message>
        <source>Basic info</source>
        <translation>Grundlæggende info</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Detaljer</translation>
    </message>
</context>
<context>
    <name>ImageView</name>
    <message>
        <source>This file contains multiple pages, please use Evince to view all pages.</source>
        <translation>Filen indeholder flere sider, brug venligst Evince til at vise alle sider.</translation>
    </message>
</context>
<context>
    <name>Importer</name>
    <message>
        <source>Open Directory</source>
        <translation>Åbn mappe</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>You have no permission to view the image</source>
        <translation>Du har ikke tilladelse til at vise dette billede</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Cancel</source>
        <translation>Annuller</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Slet</translation>
    </message>
    <message>
        <source>Image file not found</source>
        <translation>Billedfil ikke fundet</translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Name</source>
        <translation>Navn</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Type</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>Ændringsdato</translation>
    </message>
    <message>
        <source>Dimension</source>
        <translation>Dimension</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>Filstørrelse</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>Optagelsesdato</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>Eksponeringstilstand</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>Eksponeringsprogram</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>Eksponeringstid</translation>
    </message>
    <message>
        <source>Flash</source>
        <translation>Blitz</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>Blænde</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>Brændvidde</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>Maks. blænde</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>Målingstilstand</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>Hvidbalance</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>Blitzkompensering</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>Linsemodel</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>Farverum</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>Kameramodel</translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation>Dimensioner</translation>
    </message>
    <message>
        <source>Tag</source>
        <translation>Mærkat</translation>
    </message>
</context>
<context>
    <name>PrintOptionsPage</name>
    <message>
        <source>No scaling</source>
        <translation>Ingen skalering</translation>
    </message>
    <message>
        <source>Fit page to image</source>
        <translation>Tilpas side til billede</translation>
    </message>
    <message>
        <source>Fit image to page</source>
        <translation>Tilpas billede til side</translation>
    </message>
    <message>
        <source>Scale to:</source>
        <translation>Skaler til:</translation>
    </message>
    <message>
        <source>Millimeters</source>
        <translation>Millimeter</translation>
    </message>
    <message>
        <source>Centimeters</source>
        <translation>Centimeter</translation>
    </message>
    <message>
        <source>Inches</source>
        <translation>Tommer</translation>
    </message>
    <message>
        <source>Image Position</source>
        <translation>Placering af billede</translation>
    </message>
    <message>
        <source>Scaling</source>
        <translation>Skalering</translation>
    </message>
    <message>
        <source>Image Settings</source>
        <translation>Indstillinger for billede</translation>
    </message>
</context>
<context>
    <name>PrintPreviewDialog</name>
    <message>
        <source>Image Settings</source>
        <translation>Billedindstillinger</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Blinds</source>
        <translation>Persienner</translation>
    </message>
    <message>
        <source>Switcher</source>
        <translation>Skifter</translation>
    </message>
    <message>
        <source>Sliding</source>
        <translation>Glider</translation>
    </message>
    <message>
        <source>Ring</source>
        <translation>Cirkel</translation>
    </message>
    <message>
        <source>yyyy/MM/dd HH:mm:dd</source>
        <translation>dd/MM/yyyy HH:mm:dd</translation>
    </message>
</context>
<context>
    <name>RenameDialog</name>
    <message>
        <source>Confirm</source>
        <translation>Bekræft</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuller</translation>
    </message>
    <message>
        <source>Input a new name</source>
        <translation>Indtast et nyt navn</translation>
    </message>
</context>
<context>
    <name>ScanPathsDialog</name>
    <message>
        <source>Select Directory</source>
        <translation>Vælg mappe</translation>
    </message>
    <message>
        <source>This directory is disabled to sync</source>
        <translation>Denne mappe er deaktiveret til synkronisering</translation>
    </message>
    <message>
        <source>Add folder</source>
        <translation>Tilføj mappe</translation>
    </message>
    <message>
        <source>Sync Directory Management</source>
        <translation>Synkronisér mappehåndtering</translation>
    </message>
    <message>
        <source>The directory list is empty</source>
        <translation>Mappelisten er tom</translation>
    </message>
</context>
<context>
    <name>ScanPathsItem</name>
    <message>
        <source>Cancel sync</source>
        <translation>Annuller synkronisering</translation>
    </message>
    <message>
        <source>Images</source>
        <translation>Billeder</translation>
    </message>
    <message>
        <source>The device has been removed</source>
        <translation>Enheden er blevet fjernet</translation>
    </message>
    <message>
        <source>This directory no longer exists</source>
        <translation>Mappen findes ikke længere</translation>
    </message>
    <message>
        <source>Calculating...</source>
        <translation>Udregner...</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Image Viewing</source>
        <translation>Billedvisning</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Album</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Indstillinger</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Vis</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Fuldskærm</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Diasshow</translation>
    </message>
    <message>
        <source>End show</source>
        <translation>Afslut show</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopiér</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Fjern fra album</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Sæt som favorit</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Fjern fra favorit</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Rotér med uret</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Rotér mod uret</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Sæt som tapet</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Vis i filhåndtering</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Billedinfo</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Forrige</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Næste</translation>
    </message>
    <message>
        <source>Previous screen</source>
        <translation>Forrige skærm</translation>
    </message>
    <message>
        <source>Next screen</source>
        <translation>Næste skærm</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Nyt album</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Omdøb</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Hjælp</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Vis genveje</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Slet</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Forlad fuldskærm</translation>
    </message>
    <message>
        <source>Zoom in</source>
        <translation>Zoom ind</translation>
    </message>
    <message>
        <source>Zoom out</source>
        <translation>Zoom ud</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Åbn</translation>
    </message>
</context>
<context>
    <name>ShortcutEditor</name>
    <message>
        <source>Please enter a new shortcut</source>
        <translation>Indtast venligst en ny genvej</translation>
    </message>
</context>
<context>
    <name>ShortcutFrame</name>
    <message>
        <source>Shortcuts</source>
        <translation>Genveje</translation>
    </message>
    <message>
        <source>View Picture</source>
        <translation>Vis billede</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Album</translation>
    </message>
    <message>
        <source>Restore Defaults</source>
        <translation>Nulstil standarder</translation>
    </message>
</context>
<context>
    <name>ShortcutKey</name>
    <message>
        <source>View</source>
        <translation>Vis</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Fuldskærm</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Diasshow</translation>
    </message>
    <message>
        <source>End show</source>
        <translation>Afslut show</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Udskriv</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopiér</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Fjern fra album</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Sæt som favorit</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Fjern fra favorit</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Rotér med uret</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Rotér mod uret</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Sæt som tapet</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Vis i filhåndtering</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Billedinfo</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Nyt album</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Omdøb</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Slet</translation>
    </message>
</context>
<context>
    <name>SlideShowBottomBar</name>
    <message>
        <source>Previous</source>
        <translation>Forrige</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pause</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Afspil</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Næste</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Afslut</translation>
    </message>
</context>
<context>
    <name>SlideshowFrame</name>
    <message>
        <source>Slide Settings</source>
        <translation>Diasindstillinger</translation>
    </message>
    <message>
        <source>Switch effect</source>
        <translation>Skifteffekt</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Varighed</translation>
    </message>
    <message>
        <source>Switch duration</source>
        <translation>Skiftvarighed</translation>
    </message>
    <message>
        <source>second</source>
        <translation>sekund</translation>
    </message>
</context>
<context>
    <name>TTBContent</name>
    <message>
        <source>My favorite</source>
        <translation>Min favorit</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Forrige</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Næste</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>1:1 størrelse</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>Tilpas til vindue</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Rotér mod uret</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Rotér med uret</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Slet</translation>
    </message>
</context>
<context>
    <name>TTLContent</name>
    <message>
        <source>Back</source>
        <translation>Tilbage</translation>
    </message>
    <message>
        <source>Image management</source>
        <translation>Billedhåndtering</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>Min favorit</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>1:1 størrelse</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>Tilpas til vindue</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Rotér mod uret</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Rotér med uret</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Fjern fra favorit</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Sæt som favorit</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Slet</translation>
    </message>
</context>
<context>
    <name>ThumbnailWidget</name>
    <message>
        <source>No image files found</source>
        <translation>Ingen billedfiler fundet</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Åbn billede</translation>
    </message>
    <message>
        <source>Image file not found</source>
        <translation>Billedfil ikke fundet</translation>
    </message>
</context>
<context>
    <name>TitleFrame</name>
    <message>
        <source>Slide Settings</source>
        <translation>Diasindstillinger</translation>
    </message>
    <message>
        <source>Effect</source>
        <translation>Effekt</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Varighed</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Genveje</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Vis</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Album</translation>
    </message>
</context>
<context>
    <name>TopToolbar</name>
    <message>
        <source>New album</source>
        <translation>Nyt album</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Indstillinger</translation>
    </message>
</context>
<context>
    <name>ViewPanel</name>
    <message>
        <source>Timeline</source>
        <translation>Tidslinje</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>Tilføj til album</translation>
    </message>
    <message>
        <source>Add to new album</source>
        <translation>Tilføj til nyt album</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Forlad fuldskærm</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Fuldskærm</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Diasshow</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Udskriv</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopiér</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Fjern fra album</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Sæt som favorit</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Fjern fra favorit</translation>
    </message>
    <message>
        <source>Show navigation window</source>
        <translation>Vis navigationsvindue</translation>
    </message>
    <message>
        <source>Hide navigation window</source>
        <translation>Skjul navigationsvindue</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Rotér med uret</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Rotér mod uret</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Sæt som tapet</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Vis i filhåndtering</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Billedinfo</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Slet</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Åbn billede</translation>
    </message>
    <message>
        <source>All images</source>
        <translation>Alle billeder</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Omdøb</translation>
    </message>
    <message>
        <source>Draw</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>

==> deepin-image-viewer_5.9.6.orig.tar.xz: deepin-image-viewer-5.9.6/src/translations/deepin-image-viewer_da.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="da" version="2.1">
<context>
    <name>HomePageWidget</name>
    <message>
        <source>Image file not found</source>
        <translation>Billedfil ikke fundet</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Åbn billede</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Image Viewing</source>
        <translation>Billedvisning</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Indstillinger</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Fuldskærm</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Forlad fuldskærm</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Diasshow</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Omdøb</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopiér</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Slet</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Rotér med uret</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Rotér mod uret</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Sæt som tapet</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Vis i filhåndtering</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Billedinfo</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Forrige</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Næste</translation>
    </message>
    <message>
        <source>Zoom in</source>
        <translation>Zoom ind</translation>
    </message>
    <message>
        <source>Zoom out</source>
        <translation>Zoom ud</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Åbn</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Hjælp</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Vis genveje</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Image Viewer</source>
        <translation>Billedfremviser</translation>
    </message>
    <message>
        <source>Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
        <translation>Billedfremviser er et værktøj til billedfremvisning med flot brugerflade og god ydelse.</translation>
    </message>
</context>
</TS>
